==> meteor-easy-test-1.0.8.tgz: package/src/index.jsx <==
/* Import variables from dependencies modules and configuring *********************************************************/
import React from 'react';
import ReactDOM from 'react-dom';
import chai from "chai";
import jsdom from 'mocha-jsdom';
import ReactTestUtils from 'react-addons-test-utils';

expect = chai.expect;
AssertionError = chai.AssertionError;
Assertion = chai.Assertion;
assert = chai.assert;

chai.should();
chai.config.includeStack = true;
chai.use(require("sinon-chai"));

/* Import and wrapping test cases *************************************************************************************/
import * as testsObj from "/test/test.jsx";

let loadCases = () => {
    for (key in testsObj) {
        if (key !== '__esModule') {
            testsObj[key]();
        }
    }
};

/* React components ***************************************************************************************************/
const Mocha = React.createClass({
    show: (e) => {
        e.preventDefault();
        let elem = document.getElementById('mocha__pop-up');
        if (!elem.style.display || elem.style.display === "none") {
            elem.style.display = 'block';
        } else if (elem.style.display) {
            elem.style.display = 'none';
        }

    },
/*    componentWillMount: () => {
        console.log(document.head);
        let script = document.createElement('script'),
            scriptBdd = document.createElement('script');
        script.src = "https://cdn.rawgit.com/mochajs/mocha/2.2.5/mocha.js";
        scriptBdd.innerHTML = "mocha.setup('bdd');";
        document.head.appendChild(script);
        document.head.appendChild(scriptBdd);

        console.log(document.head);
    },*/
    render: function () {
        return (
            <div>
                {loadCases()}
                <a onClick={this.show} role="button" className="mocha__btn glyphicon glyphicon-asterisk"/>
                <div id="mocha__pop-up">
                    <a onClick={this.show} role="button" className="glyphicon glyphicon-remove"
                       id="mocha__pop-up--close-btn"/>
                    <div id="mocha">
                    </div>
                </div>
            </div>
        )
    },
    componentDidMount: () => {
        document.getElementById('mocha__pop-up').style.display = 'block';
        mocha.run();
    }
});

module.exports = Mocha;

==> meteor-easy-test-1.0.9.tgz: package/src/index.jsx <==
/* Import variables from dependencies modules and configuring *********************************************************/
import React from 'react';
import ReactDOM from 'react-dom';
import scriptMocha from './mocha';
import jsdom from 'mocha-jsdom';
import ReactTestUtils from 'react-addons-test-utils';
import * as testCases from "/test/test.jsx";

/* React components ***************************************************************************************************/
const TestBord = React.createClass({
    loadCases: () => {
        for (key in testCases) {
            if (key !== '__esModule') {
                testCases[key]();
            }
        }
    },
    show: (e) => {
        e.preventDefault();
        let elem = document.getElementById('mocha__pop-up');
        if (!elem.style.display || elem.style.display === "none") {
            elem.style.display = 'block';
        } else if (elem.style.display) {
            elem.style.display = 'none';
        }

    },
    componentWillMount: () => {
        scriptMocha();
        mocha.setup('bdd');
    },
    render: function () {
        return (
            <div>
                {this.loadCases()}
                <a onClick={this.show} role="button" className="mocha__btn glyphicon glyphicon-asterisk"/>
                <div id="mocha__pop-up">
                    <a onClick={this.show} role="button" className="glyphicon glyphicon-remove"
                       id="mocha__pop-up--close-btn"/>
                    <div id="mocha">
                    </div>
                </div>
            </div>
        )
    },
    componentDidMount: () => {
        document.getElementById('mocha__pop-up').style.display = 'block';
        mocha.run();
    }
});

module.exports = TestBord;
